@@ -25,6 +25,11 @@ input_container = "input"
 output_container = "output"
 
 
+def chunks(lst, n):
+    for i in range(0, len(lst), n):
+        yield lst[i:i + n]
+
+
 class TaskResult:
     def __init__(self, result, error_message, stack_trace, offset, request_id, state):
         self.result = result
@@ -105,13 +110,22 @@ class Worker:
         self._enqueue(request_id)
         return request_id
     
-    def trigger_blobs(self, blob_names: List[str], params=None):
-        guid = self._generate_id()
+    def trigger_blobs(self, blob_names: List[str], params=None, guid=None):
+        if guid is None:
+            guid = self._generate_id()
+        if params is not None:
+            params = json.dumps(params)
         request_ids = []
-        for blob_name in blob_names:
-            request_id = self._insert_blob_metadata(blob_name, params, guid)
+        for blobs_chunk in chunks(blob_names, 99):
+            batch = TableBatch()
+            for blob_name in blobs_chunk:
+                guid, request_hash, request_id = self._generate_request_id(blob_name, guid)
+                batch.insert_or_replace_entity({"PartitionKey": guid, "RowKey": request_hash, "BlobName": blob_name, "Params": params})
+                request_ids.append(request_id)
+            self.table_client.commit_batch(self.metadata_table_name, batch)
+
+        for request_id in request_ids:
             self._enqueue(request_id)
-            request_ids.append(request_id)
         return request_ids
 
     def trigger(self, data, params):
@@ -121,7 +135,7 @@ class Worker:
         
     def get_result(self, request_id):
         guid, request_hash = self._decode_id(request_id)
-        entity = self.table_client.get_entity(self.metadata_table_name, guid, request_hash, select="Result,Error,StackTrace,State,Offset")
+        entity = self.table_client.get_entity(self.metadata_table_name, guid, request_hash, select="PartitionKey,RowKey,Result,Error,StackTrace,State,Offset")
         entity = self._expand_result(entity)
         return TaskResult.create_from_request_entity(entity)
 
@@ -130,7 +144,7 @@ class Worker:
             self.table_client.query_entities(
                 self.metadata_table_name, 
                 filter="PartitionKey eq '%s'" % guid, 
-                select="Result,Error,StackTrace,State,Offset"
+                select="PartitionKey,RowKey,Result,Error,StackTrace,State,Offset"
             )
         )
         entities = [self._expand_result(e) for e in entities]
@@ -369,13 +383,8 @@ class Worker:
 
         last_piece = unicodedata.normalize("NFKD", last_piece).strip()
         if len(last_piece) > 0:
-            source = None
-            try:
-                source = json.loads(last_piece)[0].strip()
-            except:
-                pass
-            if source:
-                yield source
+            source = json.loads(last_piece)[0].strip()
+            yield source
 
     @staticmethod
     def _generate_request_id(data, guid=None):
